from pydantic import BaseModel
import datetime as dt
from typing import Optional


class Sample(BaseModel):
    id: str
    name: str
    project: str
    comment: Optional[str]
    processing_time: Optional[dt.datetime]
    received_date: Optional[dt.date]
    prepared_date: Optional[dt.date]
    sequenced_date: Optional[dt.date]
    delivery_date: Optional[dt.date]



from fastapi import APIRouter, Depends
from cg_lims.app.build.sample import build_sample
from cg_lims.app.api.deps import get_lims
from cg_lims.app import schemas

from genologics.lims import Lims
from genologics.entities import Sample


router = APIRouter()


@router.get("/{sample_id}", response_model=schemas.Sample)
def get_sample(sample_id: str, lims: Lims = Depends(get_lims)):
    """get sample"""
    genologics_sample = Sample(lims, id=sample_id)
    sample = build_sample(genologics_sample)
    return sample
